@@ -18,6 +18,7 @@ URL_ID_LOGIN = "/api/public/login/pass"
 URL_API_LOGIN = "/api/client/auth"
 URL_CREATE = "/api/client/experiment/create"
 URL_CREATE_HPO = "/api/client/experiment/create/hpo"
+URL_CERATE_ARTIFACT ="/api/client/artifact/create"
 URL_GET_HPO = "/api/client/experiment/get/hpo"
 URL_UPLOAD_LOG = "/api/client/run/log/upload"
 URL_UPLOAD_FILE = "/v1/res/file/upload"
@@ -185,6 +186,24 @@ def upload_file(http_host:str, upload_type: str, local_path: str, root_path: str
     logger.debug("upload_file() response : " + rsp["message"])
     return rsp
 
+def create_artifact(http_host:str,teamName: str, expName: str, runId: int, arti_info : ArtifactInfo):
+
+    data = {
+        "teamName": teamName,
+        "expName": expName,
+        "artifactType" : arti_info.artifact_type,
+        "artifactName" : arti_info.artifact_name,
+        "artifactMode" : arti_info.artifact_mode,
+        "artifactScope" : arti_info.artifact_scope,
+        "artifactDescription": arti_info.artifact_description,
+        "runId" : runId
+    }
+    url = parse_result_wraaper(http_host, get_use_https(), URL_CERATE_ARTIFACT)  # TO-DO:
+    rsp = post(
+        url, data=data
+    )
+    logger.debug("create_artifact() response : " + rsp["message"])
+    return rsp
 def update_config(http_host:str, run_id: int , exp_name: str, team_name: str , items: list):
     item_list = [{"key": k, "value": v} for (k, v) in items] if items else []
     data = {
