@@ -328,23 +328,30 @@ def upload_artifact(run_id: int, artifact: Artifact, artifact_digest: str, teamN
                 "expName":"{expName}",
                 "artifact_entry":"{entry_list}",
             )""")
+    if get_use_grpc():
+        rsp: UploadArtifactResponse = get_stub().upload_artifact(UploadArtifactRequest(
+            artifact=ArtifactRecord(
+                run_id=run_id,
+                type=artifact.type,
+                name=artifact.name,
+                digest=artifact_digest,
+                description=artifact.desc,
+                versioning=artifact.versioning,
+                metadata=json.dumps(artifact.meta_data),
+                teamName=teamName,
+                expName=expName,
+                artifact_entry=entry_list,
+            ),
+            authorization=f"Bearer {http_interface.get_jwt_key()}",
+        ))
+        return rsp.artifact_id if rsp.rsp_result.result == "success" else None
+    else:
+        arti_mode = "REPOT" if artifact.versioning else "FILES"
+        arti_info =ArtifactInfo(artifact_type=artifact.type, artifact_name=artifact.name, artifact_description=artifact.desc, artifact_scope="PRIVT", artifact_mode = arti_mode )
+        rsp = http_interface.create_artifact(teamName= teamName, expName= expName, runId= run_id, arti_info= arti_info)
+        return  rsp.artifact_id  if rsp.result == "success" else None
+
 
-    rsp: UploadArtifactResponse = get_stub().upload_artifact(UploadArtifactRequest(
-        artifact=ArtifactRecord(
-            run_id=run_id,
-            type=artifact.type,
-            name=artifact.name,
-            digest=artifact_digest,
-            description=artifact.desc,
-            versioning=artifact.versioning,
-            metadata=json.dumps(artifact.meta_data),
-            teamName=teamName,
-            expName=expName,
-            artifact_entry=entry_list,
-        ),
-        authorization=f"Bearer {http_interface.get_jwt_key()}",
-    ))
-    return rsp.artifact_id if rsp.rsp_result.result == "success" else None
 
 
 def use_artifact(name: str, type: str, tag: str, team_name: str, exp_name: str, run_id: int) -> Tuple[int,
