@@ -10,8 +10,9 @@ def login(key: str=None, id: str =None, pw: str=None) -> (bool, str):
     #assert_that(key).is_not_none()
     if key is None and id is None:
         if util.is_notebook():
+            import getpass
             id = input('Enter your email:')
-            pw = input('Enter your password:')
+            pw = getpass.getpass('Enter your password:')
         else:
             assert_that(id).is_not_none()
             assert_that(pw).is_not_none()
